@@ -13,9 +13,8 @@ import string
 import StringIO
 import sys
 
-from common import AGENT_NAME, HOST
-
-PORT = 9871
+import config
+from common import AGENT_NAME
 
 class BottleClientError(Exception):
 	def __init__(self, message, detail=None):
@@ -41,9 +40,10 @@ class BottleClient:
 	###   CGI   ###
 	def send_cgi_request(self, request, action="/bottle2.cgi", response=1):
 		try:
-			http = httplib.HTTP(HOST)
+			http = httplib.HTTP(config.get('slpp_server', 'http_conn'),
+								config.get('slpp_server', 'http_port', 'int'))
 			http.putrequest("POST", action)
-			http.putheader("Host", HOST)
+			http.putheader("Host", config.get('slpp_server', 'http_host'))
 			http.putheader("From", AGENT_NAME)
 			http.putheader("Accept", "text/html, text/plain")
 			http.putheader("Content-type", "application/x-www-form-urlencoded")
@@ -130,7 +130,8 @@ class BottleClient:
 	def connect(self):
 		try:
 			self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-			self.sock.connect((HOST, PORT))
+			self.sock.connect((config.get('slpp_server', 'slpp_conn'),
+							   config.get('slpp_server', 'slpp_port', 'int')))
 		except socket.error, e:
 			raise BottleClientError("cannot connect to the server", str(e))
 	def makefile(self, blocking=1):
