@@ -10,10 +10,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: config.py,v 1.8 2008/05/18 08:03:28 atzm Exp $
+# $Id: config.py,v 1.12 2009/12/15 17:16:50 atzm Exp $
 
 __author__ = '$Author: atzm $'
-__version__ = '$Revision: 1.8 $'
+__version__ = '$Revision: 1.12 $'
 
 import common
 import os, ConfigParser
@@ -79,6 +79,8 @@ def init():
 		['general', 'connect_all', 'False'],
 		['general', 'auto_reset_editor', 'True'],
 		['general', 'logging_sent_script', 'True'],
+		['migemo', 'migemo_enabled', 'False'],
+		['migemo', 'migemo_dict', ''],
 		['sstp_server', 'forward_local', 'True'],
 		['sstp_server', 'forward_to', str(SSTP_FORWARD_ALL)],
 		['script', 'initial_script', r'\t\u\s[10]\h\s[0]|\e'],
@@ -98,6 +100,11 @@ def init():
 		['logwindow', 'new_page_placement', str(LOGWINDOW_PAGE_PLACEMENT_NEXT)],
 		['logwindow', 'tab_placement', str(LOGWINDOW_TAB_PLACEMENT_TOP)],
 		['browser', 'browser_command', "mozilla -remote 'openFile(%s,new-tab)'"],
+		['slpp_server', 'slpp_conn', 'bottle.mikage.to'],
+		['slpp_server', 'slpp_port', 9871],
+		['slpp_server', 'http_conn', 'bottle.mikage.to'],
+		['slpp_server', 'http_port', 80],
+		['slpp_server', 'http_host', 'bottle.mikage.to'],
 		['download', 'auto_download', 'False'],
 		['download', 'logging_download_history', 'True'],
 		['download', 'download_type', ' '.join(common.DL_SUFFIX_PATTERNS.keys())],
@@ -115,6 +122,9 @@ def init():
 		['gviewer', 'height', '240'],
 		['gviewer', 'use_gviewer', 'False'],
 		['gviewer', 'draw_number', 'False'],
+		['gviewer', 'use_alias', 'False'],
+		['gviewer', 'use_sequential', 'False'],
+		['gviewer', 'seq_wait1', '50'],
 		['gviewer', 'sticky', 'False'],
 		['gviewer', 'auto_open', 'False'],
 		['gviewer', 'auto_close', 'False'],
