@@ -10,13 +10,14 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: downloader.py,v 1.16 2004/09/21 12:07:17 atzm Exp $
+# $Id: downloader.py,v 1.18 2005/09/08 20:03:43 atzm Exp $
 #
 
 import os, sys, re, time, string
 import urllib
 from threading import Thread
 from common import *
+import config
 
 if os.name == 'posix':
 	import fcntl
@@ -24,25 +25,32 @@ else:
 	import msvcrt
 
 class Downloader(Thread):
-	def __init__(self, verbose=False, dic={}, logging=True, script="", logpath=None, dlbox=None):
+	def __init__(self, verbose=False, script="", logpath=None, dlbox=None):
 		self.verbose = verbose
-		if dic:
-			self.set_pattern(dic)
-
 		self.script  = script
-		self.logging = logging
+		self.set_pattern(self.create_dic())
 
 		if logpath is None:
 			self.logpath = os.path.join(open_bottlecase(), 'download.log')
 		else:
 			self.set_logpath(logpath)
 		if dlbox is None:
-			self.dlbox   = open_bottlecase(os.path.join(LIBDIR, 'download'))
+			self.dlbox = open_bottlecase(os.path.join(LIBDIR, 'download'))
 		else:
 			self.set_dlbox(dlbox)
 
 		Thread.__init__(self)
 
+	def create_dic(self):
+		dic = {}
+		trues = config.get('download', 'download_type').split()
+		for key in DL_SUFFIX_PATTERNS.keys():
+			if key in trues:
+				dic[key] = True
+			else:
+				dic[key] = False
+		return dic
+
 	def run(self):
 		urls = self.find_url_from_script()
 		self.get_files(urls)
@@ -84,9 +92,6 @@ class Downloader(Thread):
 			self.file_regex    = re.compile('^$')
 			self.url_regex     = re.compile('^$')
 
-	def set_logging(self, logging):
-		self.logging = logging
-
 	def get_files(self, urls):
 		if not urls:
 			return
@@ -120,7 +125,7 @@ class Downloader(Thread):
 			except:
 				pass
 
-			if self.logging:
+			if config.get('download', 'logging_download_history', 'boolean'):
 				self.write_log(url, filename)
 
 	def find_url_from_script(self, script=None):
@@ -180,20 +185,14 @@ class Downloader(Thread):
 
 if __name__ == "__main__":
 	verbose = True
-	dic = {
-		'png': True, 'mpg': True, 'jpg': True, 'gif': True, 'bmp':  True, 'mpg': True, 'mp3':  True,
-		'ogg': True, 'wmv': True, 'wma': True, 'avi': True, 'mov':  True, 'ram': True, 'swf':  True,
-		'nar': True, 'zip': True, 'lzh': True, 'tgz': True, 'tbz2': True, 'txt': True, 'html': True,
-		}
-	logging = True
 	loggingpath = os.path.expanduser('~/tmp/test/dl.log')
 	dlbox = os.path.expanduser('~/tmp/test')
 
 	ths = []
-	for i in range(200):
+	for i in xrange(200):
 		url1 = r'\URL[http://127.0.0.1/index.html]'
 		url2 = r'\URL[http://127.0.0.1/index.xml]'
-		ths.append(Downloader(verbose, dic, logging, url1+url2, loggingpath, dlbox))
+		ths.append(Downloader(verbose, url1+url2, loggingpath, dlbox))
 
 	for t in ths:
 		t.start()
