@@ -13,7 +13,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: gbottler.py,v 1.181 2008/05/16 20:43:48 atzm Exp $
+# $Id: gbottler.py,v 1.183 2009/12/28 15:22:17 atzm Exp $
 #
 
 import os, sys, string, re, gettext, getopt
@@ -235,9 +235,7 @@ class Application:
 
 		self.logwindow = LogWindow(self)
 
-		ghostmanager = GhostManager(os.path.join(open_bottlecase(), 'gviewer', 'ghost.txt'),
-									os.path.join(open_bottlecase(), 'gviewer', 'Ghost'),
-									self.logwindow.generate_ghost_list)
+		ghostmanager    = GhostManager(os.path.join(open_bottlecase(), 'gviewer', 'ghost.txt'))
 		self.svgmanager = SVGManagerWindow(self, ghostmanager)
 		self.gvwindow   = GVWindow(ghostmanager) # must watch same instance of GhostManager
 
@@ -1039,18 +1037,14 @@ Public License instead of this License."""
 		gtk.AboutDialog.__init__(self)
 		self.set_name(APP)
 		self.set_version(VER)
-		self.set_copyright("Copyright (C) 2004-'05 GBottler Project all rights reserved")
+		self.set_copyright("Copyright (C) 2004-'09 GBottler Project all rights reserved")
 		self.set_authors([
-			"Copyright (C) 2004-'05 Atzm WATANABE",
+			"Copyright (C) 2004-'09 Atzm WATANABE",
 			"Copyright (C) 2004-'05 Takuya Kawahara",
 			"Copyright (C) 2001-'02 Tamito KAJIYAMA",
-			])
+		])
 		self.set_website('http://gbottler.sourceforge.jp/')
 		self.set_license(copying)
-		#try:
-		#	self.set_logo(gtk.gdk.pixbuf_new_from_file(logo))
-		#except gobject.GError:
-		#	pass
 		self.connect('delete-event', lambda x, y: self.destroy())
 
 def usage():
@@ -1080,7 +1074,7 @@ def main():
 		usage()
 
 	port = 9801
-	host = "localhost" # default - localhost:9801
+	host = "localhost"
 
 	# check environment variables
 	val = os.environ.get("BOTTLER_PORT")
