@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logfetchdialog.py,v 1.4 2005/08/29 20:28:58 atzm Exp $
+# $Id: logfetchdialog.py,v 1.6 2008/05/22 10:36:04 atzm Exp $
 #
 
 import gtk
@@ -31,6 +31,8 @@ class LogFetchDialog:
 		adj = gtk.Adjustment(1.0, 1.0, 100.0, 1.0, 5.0, 0.0)
 		self.timespin  = gtk.SpinButton(adj, 0, 0)
 		self.combo     = gtk.combo_box_new_text()
+		self.timespin.connect('focus-in-event', lambda w, e: self.timeradio.set_active(True))
+		self.combo.connect('changed', lambda w: self.timeradio.set_active(True))
 		for msg in self.time_msg:
 			self.combo.append_text(msg)
 		self.combo.set_active(0)
@@ -84,6 +86,20 @@ class LogFetchDialog:
 		self.to_d_spin = gtk.SpinButton(adj, 0, 0)
 		self.to_d_spin.set_value(float(d))
 		self.to_d_spin.show()
+##
+		self.from_cal_button = gtk.Button(unicode(_('...'), 'utf-8'))
+		self.from_cal_button.connect('clicked', self._open_calendar,
+									 self.from_y_spin, self.from_m_spin, self.from_d_spin)
+		self.from_cal_button.show()
+		self.to_cal_button = gtk.Button(unicode(_('...'), 'utf-8'))
+		self.to_cal_button.connect('clicked', self._open_calendar,
+								   self.to_y_spin, self.to_m_spin, self.to_d_spin)
+		self.to_cal_button.show()
+##
+		for s in [self.from_y_spin, self.from_m_spin, self.from_d_spin,
+				  self.to_y_spin,   self.to_m_spin,   self.to_d_spin,
+				  self.from_cal_button, self.to_cal_button]:
+			s.connect('focus-in-event', lambda w, e: self.dateradio.set_active(True))
 ##
 		self.datebox = gtk.HBox()
 		self.datebox.set_border_width(5)
@@ -93,10 +109,12 @@ class LogFetchDialog:
 		self.datebox.pack_start(self.from_y_spin)
 		self.datebox.pack_start(self.from_m_spin)
 		self.datebox.pack_start(self.from_d_spin)
+		self.datebox.pack_start(self.from_cal_button)
 		self.datebox.pack_start(self.from_label)
 		self.datebox.pack_start(self.to_y_spin)
 		self.datebox.pack_start(self.to_m_spin)
 		self.datebox.pack_start(self.to_d_spin)
+		self.datebox.pack_start(self.to_cal_button)
 
 # === Bring PastBox and DateBox together to Frame === #
 		self.dayvbox = gtk.VBox()
@@ -257,3 +275,30 @@ class LogFetchDialog:
 					 int(to_date[4:6]),
 					 int(to_date[6:])]
 		return dic
+
+	def _open_calendar(self, button, y_spin, m_spin, d_spin):
+		d = gtk.Dialog(_('Calendar'), self.window,
+					   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR)
+		d.connect('delete-event', lambda x, y: x.response(gtk.RESPONSE_OK))
+
+		cal = gtk.Calendar()
+		cal.connect('day-selected-double-click', self._day_selected, d, y_spin, m_spin, d_spin)
+
+		year  = y_spin.get_value_as_int()
+		month = m_spin.get_value_as_int() - 1
+		day   = d_spin.get_value_as_int()
+
+		cal.select_month(month, year)
+		cal.select_day(day)
+
+		d.vbox.pack_start(cal)
+		d.show_all()
+		d.run()
+		d.destroy()
+
+	def _day_selected(self, calendar, dialog, y_spin, m_spin, d_spin):
+		year, month, day = calendar.get_date()
+		y_spin.set_value(year)
+		m_spin.set_value(month + 1)
+		d_spin.set_value(day)
+		dialog.response(gtk.RESPONSE_OK)
