@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logwindow.py,v 1.37 2007/09/14 19:07:32 atzm Exp $
+# $Id: logwindow.py,v 1.38 2009/12/13 19:06:08 atzm Exp $
 #
 
 import gtk, gobject
@@ -809,21 +809,6 @@ class LogWindow:
 		self.tab_pos_changed()
 	### notify preference changed end
 
-	def generate_ghost_list(self):
-		glist = []
-
-		for gname in self.app.uniq_ghosts():
-			if gname not in glist:
-				glist.append(gname)
-
-		for n in xrange(self.logbook.get_n_pages()):
-			loglist = self.logbook.get_nth_page(n).get_child()
-			for r in xrange(loglist.rows()):
-				gname = loglist.get_text(r, loglist.LISTSTORE_GHOST)
-				if gname not in glist:
-					glist.append(gname)
-
-		return glist
 
 class CompressFileChooser(gtk.FileChooserDialog):
 	def __init__(self, title='', parent=None, action=gtk.FILE_CHOOSER_ACTION_OPEN, buttons=None, backend=''):
