@@ -11,10 +11,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: phrasemanager.py,v 1.9 2005/09/21 15:29:20 atzm Exp $
+# $Id: phrasemanager.py,v 1.10 2005/10/11 10:28:56 atzm Exp $
 #
 
-__version__ = '$Revision: 1.9 $'
+__version__ = '$Revision: 1.10 $'
 __author__ = '$Author: atzm $'
 
 import os, sys
@@ -30,9 +30,8 @@ import config
 
 from viewer.ghostmanager import OrderedDictionary
 
-from xml.sax import saxexts, saxutils
-from xml.sax.handler import ContentHandler
-from xml.parsers import expat
+import xml.sax.saxutils
+import xml.parsers.expat
 
 class PhraseParser:
 	def __init__(self, func=lambda x, y: None):
@@ -40,7 +39,7 @@ class PhraseParser:
 		self.clear()
 
 	def clear(self):
-		self.parser = expat.ParserCreate()
+		self.parser = xml.parsers.expat.ParserCreate()
 		self.parser.StartElementHandler = self.startElement
 		self.parser.EndElementHandler = self.endElement
 
@@ -491,16 +490,16 @@ class PhraseEditor(gtk.Window):
 						tagname = 'menubar'
 					else:
 						tagname = 'menu'
-					xmlstr.append('%s<%s name=%s>' % (nest, tagname, saxutils.quoteattr(name)))
+					xmlstr.append('%s<%s name=%s>' % (nest, tagname, xml.sax.saxutils.quoteattr(name)))
 					_create_xml(model, model.iter_children(titer), xmlstr, level+1)
 					xmlstr.append('%s</%s>' % (nest, tagname))
 				else:
-					if insert: insert = ' insert=%s' % saxutils.quoteattr(insert)
+					if insert: insert = ' insert=%s' % xml.sax.saxutils.quoteattr(insert)
 					else: insert = ''
-					if accel: accel = ' accel=%s' % saxutils.quoteattr(accel)
+					if accel: accel = ' accel=%s' % xml.sax.saxutils.quoteattr(accel)
 					else: accel = ''
 					xmlstr.append('%s<menuitem name=%s%s%s/>' % \
-								  (nest, saxutils.quoteattr(name), insert, accel))
+								  (nest, xml.sax.saxutils.quoteattr(name), insert, accel))
 				titer = model.iter_next(titer)
 				if titer is None:
 					break
