@@ -1,4 +1,4 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  preferences.py - New preference manipulator for GBottler
 #  Copyright (C) 2005 by Atzm WATANABE <sitosito@p.chan.ne.jp>
@@ -10,11 +10,11 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: preferences.py,v 1.7 2008/05/18 08:03:28 atzm Exp $
+# $Id: preferences.py,v 1.12 2009/12/15 17:16:50 atzm Exp $
 #
 
 __author__ = '$Author: atzm $'
-__version__ = '$Revision: 1.7 $'
+__version__ = '$Revision: 1.12 $'
 
 import gtk, gobject
 
@@ -44,6 +44,7 @@ class PreferenceDialog(gtk.Dialog):
 		items.append([_('Network')] + self.__create_network_page())
 		items.append([_('Fonts')] + self.__create_font_page())
 		items.append([_('GViewer')] + self.__create_gviewer_page())
+		items.append([_('Misc')] + self.__create_misc_page())
 		items.append([_('LUID'), self.__create_luid_page(), {}])
 
 		self.__widgets_dict = {}
@@ -179,16 +180,16 @@ class PreferenceDialog(gtk.Dialog):
 
 	def __create_general_page(self):
 		genframe, gendic = self.__create_general_frame()
-		sstpframe, sstpdic  = self.__create_sstp_frame()
 		scriptframe, scriptdic = self.__create_initial_script_frame()
+		browserframe, browserdic = self.__create_browser_frame()
 
 		general_page_dict = OrderedDictionary()
 		general_page_dict['general'] = gendic
-		general_page_dict['sstp_server'] = sstpdic
 		general_page_dict['script'] = scriptdic
+		general_page_dict['browser'] = browserdic
 
 		general_page = gtk.VBox()
-		for widget in [genframe, sstpframe, scriptframe]:
+		for widget in [genframe, scriptframe, browserframe]:
 			general_page.pack_start(widget, False, False, 0)
 		return [general_page, general_page_dict]
 
@@ -203,29 +204,6 @@ class PreferenceDialog(gtk.Dialog):
 		genframe = create_frame(_('General'), gendic)
 		return genframe, gendic
 
-	def __create_sstp_frame(self):
-		sstpdic = OrderedDictionary()
-		sstpdic['forward_local'] = gtk.CheckButton(_('Forward'))
-		sstpdic['forward_to'] = gtk.combo_box_new_text()
-		sstpdic['forward_to'].append_text(_('Accept All'))
-		sstpdic['forward_to'].append_text(_('Forward only listed Ghost'))
-		sstpdic['forward_to'].set_active(0)
-		sstpdic['forward_local'].connect('toggled', lambda x: sstpdic['forward_to'].set_sensitive(x.get_active()))
-
-		hbox = gtk.HBox()
-		hbox.set_border_width(5)
-		hbox.pack_start(sstpdic['forward_to'])
-
-		vbox = gtk.VBox()
-		for item in [sstpdic['forward_local'], hbox]:
-			vbox.set_border_width(5)
-			vbox.pack_start(item)
-		frame = gtk.Frame(_('SSTP server'))
-		frame.set_border_width(5)
-		frame.add(vbox)
-
-		return frame, sstpdic
-
 	def __create_initial_script_frame(self):
 		scriptdic = OrderedDictionary()
 		scriptdic['initial_script'] = gtk.Entry()
@@ -243,6 +221,23 @@ class PreferenceDialog(gtk.Dialog):
 		scriptframe.add(scriptbox)
 		return scriptframe, scriptdic
 
+	def __create_browser_frame(self):
+		browdict = OrderedDictionary()
+		browdict['browser_command'] = gtk.Entry()
+
+		hbox = gtk.HBox()
+		hbox.set_border_width(5)
+		hbox.pack_start(browdict['browser_command'])
+
+		browbox = gtk.VBox()
+		browbox.pack_start(hbox, False, False, 5)
+		browbox.pack_start(gtk.Label(_('Replace %s to URL')), False, False, 5)
+
+		browframe = gtk.Frame(_('Command to run browser'))
+		browframe.set_border_width(5)
+		browframe.add(browbox)
+		return browframe, browdict
+
 	def __create_key_page(self):
 		keframe, kedic   = self.__create_key_enter_frame()
 		kseframe, ksedic = self.__create_key_shift_enter_frame()
@@ -427,79 +422,72 @@ class PreferenceDialog(gtk.Dialog):
 		return frame, logwindic
 
 	def __create_network_page(self):
-		browserframe, browserdic = self.__create_browser_frame()
-		downloadframe, downloaddic = self.__create_download_frame()
+		slppframe, slppdic = self.__create_slpp_frame()
+		sstpframe, sstpdic  = self.__create_sstp_frame()
 
 		network_page_dict = OrderedDictionary()
-		network_page_dict['browser'] = browserdic
-		network_page_dict['download'] = downloaddic
+		network_page_dict['sstp_server'] = sstpdic
+		network_page_dict['slpp_server'] = slppdic
 
 		network_page = gtk.VBox()
-		for widget in [browserframe, downloadframe]:
+		for widget in [sstpframe, slppframe]:
 			network_page.pack_start(widget, False, False, 0)
 		return [network_page, network_page_dict]
 
-	def __create_browser_frame(self):
-		browdict = OrderedDictionary()
-		browdict['browser_command'] = gtk.Entry()
+	def __create_sstp_frame(self):
+		sstpdic = OrderedDictionary()
+		sstpdic['forward_local'] = gtk.CheckButton(_('Forward'))
+		sstpdic['forward_to'] = gtk.combo_box_new_text()
+		sstpdic['forward_to'].append_text(_('Accept All'))
+		sstpdic['forward_to'].append_text(_('Forward only listed Ghost'))
+		sstpdic['forward_to'].set_active(0)
+		sstpdic['forward_local'].connect('toggled', lambda x: sstpdic['forward_to'].set_sensitive(x.get_active()))
 
 		hbox = gtk.HBox()
 		hbox.set_border_width(5)
-		hbox.pack_start(browdict['browser_command'])
+		hbox.pack_start(sstpdic['forward_to'])
 
-		browbox = gtk.VBox()
-		browbox.pack_start(hbox, False, False, 5)
-		browbox.pack_start(gtk.Label(_('Replace %s to URL')), False, False, 5)
+		vbox = gtk.VBox()
+		for item in [sstpdic['forward_local'], hbox]:
+			vbox.set_border_width(5)
+			vbox.pack_start(item)
+		frame = gtk.Frame(_('SSTP server'))
+		frame.set_border_width(5)
+		frame.add(vbox)
 
-		browframe = gtk.Frame(_('Command to run browser'))
-		browframe.set_border_width(5)
-		browframe.add(browbox)
-		return browframe, browdict
+		return frame, sstpdic
 
-	def __create_download_frame(self):
-		dldict = OrderedDictionary()
-		dldict['auto_download'] = gtk.CheckButton(_('Auto download when receive script contained URL'))
-		dldict['logging_download_history'] = gtk.CheckButton(_('Logging history'))
-		dldict['logging_download_history'].set_sensitive(False)
+	def __create_slpp_frame(self):
+		slppdict = OrderedDictionary()
 
-		# make table
-		rows = 4
-		ex_table = gtk.Table(7, rows)
+		adj1 = gtk.Adjustment(0.0, 0.0, 65535.0, 1.0, 5.0, 0.0)
+		slppdict['slpp_conn'] = gtk.Entry()
+		slppdict['slpp_port'] = gtk.SpinButton(adj1, 0, 0)
 
-		keys = common.DL_SUFFIX_PATTERNS.keys()
-		keys.sort()
+		adj2 = gtk.Adjustment(0.0, 0.0, 65535.0, 1.0, 5.0, 0.0)
+		slppdict['http_conn'] = gtk.Entry()
+		slppdict['http_port'] = gtk.SpinButton(adj2, 0, 0)
 
-		length = len(keys) / rows + 1
-		itemlist = [keys[length*i:length*(i+1)] for i in xrange(rows)]
+		slppdict['http_host'] = gtk.Entry()
 
-		dldict['download_type'] = []
-		for i in xrange(len(itemlist)):
-			for j in xrange(len(itemlist[i])):
-				button = gtk.CheckButton(itemlist[i][j])
-				button.set_sensitive(False)
-				dldict['download_type'].append(button)
-				ex_table.attach(button, j, j+1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+		table = gtk.Table(4, 3)
+		table.attach(gtk.Label(_('SLPP Connect To')), 0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(slppdict['slpp_conn'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(gtk.Label(_('SLPP Port')), 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(slppdict['slpp_port'], 3, 4, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 
-		def check_toggled(widget):
-			state = widget.get_active()
-			for i in [dldict['logging_download_history']] + dldict['download_type']:
-				i.set_sensitive(state)
-		dldict['auto_download'].connect('toggled', check_toggled)
+		table.attach(gtk.Label(_('HTTP Connect To')), 0, 1, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(slppdict['http_conn'], 1, 2, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(gtk.Label(_('HTTP Port')), 2, 3, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(slppdict['http_port'], 3, 4, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
 
-		ex_frame = gtk.Frame(_('Supported file types'))
-		ex_frame.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
-		ex_frame.set_border_width(5)
-		ex_frame.add(ex_table)
+		table.attach(gtk.Label(_('HTTP Host')), 0, 1, 2, 3, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(slppdict['http_host'], 1, 2, 2, 3, gtk.FILL, gtk.FILL, 3, 3)
 
-		dlbox = gtk.VBox()
-		for widget in [dldict['auto_download'], dldict['logging_download_history'], ex_frame]:
-			widget.set_border_width(5)
-			dlbox.pack_start(widget, False, False, 0)
-
-		dlframe = gtk.Frame(_('Download'))
-		dlframe.set_border_width(5)
-		dlframe.add(dlbox)
-		return dlframe, dldict
+		slppframe = gtk.Frame(_('SLPP Server (Experimental)'))
+		slppframe.set_border_width(5)
+		slppframe.add(table)
+		return slppframe, slppdict
 
 	def __create_font_page(self):
 		fontframe, fontdic = self.__create_font_frame()
@@ -600,6 +588,12 @@ class PreferenceDialog(gtk.Dialog):
 		gvdict['wait_w1'] = gtk.SpinButton(adj, 0, 0)
 
 		gvdict['draw_number'] = gtk.CheckButton(_('Display surface number'))
+		gvdict['use_alias'] = gtk.CheckButton(_('Use Surface Aliases'))
+		gvdict['use_sequential'] = gtk.CheckButton(_('Use Sequential Splite'))
+
+		adj = gtk.Adjustment(1.0, 0.0, 10000.0, 1.0, 5.0, 0.0)
+		gvdict['seq_wait1'] = gtk.SpinButton(adj, 0, 0)
+
 		gvdict['sticky'] = gtk.CheckButton(_('Stick GViewer'))
 		gvdict['auto_open'] = gtk.CheckButton(_('Auto open GViewer when play script'))
 		gvdict['raise_before_play'] = gtk.CheckButton(_('Raise GViewer before play script'))
@@ -610,13 +604,21 @@ class PreferenceDialog(gtk.Dialog):
 
 		def check_toggled(widget):
 			state = widget.get_active()
-			for i in [gvdict[t] for t in ['wait_char', 'wait_w1', 'draw_number', 'sticky', 'auto_open', 'raise_before_play', 'sink_after_play']]:
+			for i in [gvdict[t] for t in ['wait_char', 'wait_w1', 'use_alias', 'use_sequential', 'draw_number', 'sticky', 'auto_open', 'raise_before_play', 'sink_after_play']]:
 				i.set_sensitive(state)
-			state = state and gvdict['sink_after_play'].get_active()
-			gvdict['sink_timer'].set_sensitive(state)
+			state1 = state and gvdict['sink_after_play'].get_active()
+			gvdict['sink_timer'].set_sensitive(state1)
+			state2 = state and gvdict['use_sequential'].get_active()
+			gvdict['seq_wait1'].set_sensitive(state2)
 		gvdict['use_gviewer'].connect('toggled', check_toggled)
 		check_toggled(gvdict['use_gviewer'])
 
+		def check_toggled_seq(widget):
+			state = widget.get_active() and gvdict['use_gviewer'].get_active()
+			gvdict['seq_wait1'].set_sensitive(state)
+		gvdict['use_sequential'].connect('toggled', check_toggled_seq)
+		check_toggled_seq(gvdict['use_sequential'])
+
 		def check_toggled_sink(widget):
 			state = widget.get_active() and gvdict['use_gviewer'].get_active()
 			gvdict['sink_timer'].set_sensitive(state)
@@ -636,8 +638,13 @@ class PreferenceDialog(gtk.Dialog):
 		sink_table.attach(gvdict['sink_timer'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 		sink_table.attach(gtk.Label(_('milli seconds')), 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 
+		seq_wait_table = gtk.Table(1, 3)
+		seq_wait_table.attach(gtk.Label(_('Wait for a ">"')), 0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		seq_wait_table.attach(gvdict['seq_wait1'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		seq_wait_table.attach(gtk.Label(_('milli seconds')), 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+
 		viewbox = gtk.VBox()
-		for widget in [gvdict['use_gviewer'], wait_table, gvdict['draw_number'], gvdict['sticky'], gvdict['auto_open'], gvdict['raise_before_play'], gvdict['sink_after_play'], sink_table]:
+		for widget in [gvdict['use_gviewer'], wait_table, gvdict['draw_number'], gvdict['use_alias'], gvdict['use_sequential'], seq_wait_table, gvdict['sticky'], gvdict['auto_open'], gvdict['raise_before_play'], gvdict['sink_after_play'], sink_table]:
 			widget.set_border_width(5)
 			viewbox.pack_start(widget, False, False, 0)
 
@@ -653,6 +660,109 @@ class PreferenceDialog(gtk.Dialog):
 
 		return [viewerpage, gvpage_dict]
 
+	def __create_misc_page(self):
+		downloadframe, downloaddic = self.__create_download_frame()
+		migemoframe, migemodic = self.__create_migemo_frame()
+
+		misc_page_dict = OrderedDictionary()
+		misc_page_dict['migemo'] = migemodic
+		misc_page_dict['download'] = downloaddic
+
+		misc_page = gtk.VBox()
+		for widget in [migemoframe, downloadframe]:
+			misc_page.pack_start(widget, False, False, 0)
+		return [misc_page, misc_page_dict]
+
+	def __create_migemo_frame(self):
+		migemodic = OrderedDictionary()
+		migemodic['migemo_enabled'] = gtk.CheckButton(_('Enable Migemo'))
+		migemodic['migemo_dict'] = gtk.Entry()
+		migemodic['migemo_dict'].set_sensitive(False)
+
+		def open_file_chooser_dialog(widget=None, *args):
+			filew = gtk.FileChooserDialog(title=_('Select Dictionary'),
+										  parent=self,
+										  action=gtk.FILE_CHOOSER_ACTION_OPEN,
+										  buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+												   gtk.STOCK_OK, gtk.RESPONSE_OK))
+			filew.set_select_multiple(False)
+			filew.connect('destroy', lambda x: filew.destroy())
+			filew.show()
+			if filew.run() == gtk.RESPONSE_OK:
+				migemodic['migemo_dict'].set_text(filew.get_filename())
+			filew.destroy()
+
+		btn = common.get_icon_button(gtk.STOCK_OPEN, size=gtk.ICON_SIZE_BUTTON, relief=gtk.RELIEF_NORMAL)
+		btn.connect('clicked', open_file_chooser_dialog)
+		btn.set_sensitive(False)
+
+		def _toggle_migemo_enabled(checkbutton):
+			flag = checkbutton.get_active()
+			migemodic['migemo_dict'].set_sensitive(flag)
+			btn.set_sensitive(flag)
+
+		migemodic['migemo_enabled'].connect('toggled', _toggle_migemo_enabled)
+
+		hbox = gtk.HBox()
+		hbox.pack_start(gtk.Label(_('Path to Dictionary')), False, False, 5)
+		hbox.pack_start(migemodic['migemo_dict'])
+		hbox.pack_start(btn, False, False, 5)
+
+		vbox = gtk.VBox()
+		vbox.set_border_width(5)
+		vbox.pack_start(migemodic['migemo_enabled'])
+		vbox.pack_start(hbox)
+
+		migemoframe = gtk.Frame(_('Migemo'))
+		migemoframe.set_border_width(5)
+		migemoframe.add(vbox)
+		return migemoframe, migemodic
+
+	def __create_download_frame(self):
+		dldict = OrderedDictionary()
+		dldict['auto_download'] = gtk.CheckButton(_('Auto download when receive script contained URL'))
+		dldict['logging_download_history'] = gtk.CheckButton(_('Logging history'))
+		dldict['logging_download_history'].set_sensitive(False)
+
+		# make table
+		rows = 4
+		ex_table = gtk.Table(7, rows)
+
+		keys = common.DL_SUFFIX_PATTERNS.keys()
+		keys.sort()
+
+		length = len(keys) / rows + 1
+		itemlist = [keys[length*i:length*(i+1)] for i in xrange(rows)]
+
+		dldict['download_type'] = []
+		for i in xrange(len(itemlist)):
+			for j in xrange(len(itemlist[i])):
+				button = gtk.CheckButton(itemlist[i][j])
+				button.set_sensitive(False)
+				dldict['download_type'].append(button)
+				ex_table.attach(button, j, j+1, i, i+1, gtk.FILL, gtk.FILL, 3, 3)
+
+		def check_toggled(widget):
+			state = widget.get_active()
+			for i in [dldict['logging_download_history']] + dldict['download_type']:
+				i.set_sensitive(state)
+		dldict['auto_download'].connect('toggled', check_toggled)
+
+		ex_frame = gtk.Frame(_('Supported file types'))
+		ex_frame.set_shadow_type(gtk.SHADOW_ETCHED_OUT)
+		ex_frame.set_border_width(5)
+		ex_frame.add(ex_table)
+
+		dlbox = gtk.VBox()
+		for widget in [dldict['auto_download'], dldict['logging_download_history'], ex_frame]:
+			widget.set_border_width(5)
+			dlbox.pack_start(widget, False, False, 0)
+
+		dlframe = gtk.Frame(_('Download'))
+		dlframe.set_border_width(5)
+		dlframe.add(dlbox)
+		return dlframe, dldict
+
 	def __create_luid_page(self):
 		def set_columns(treeview, columns):
 			for i in xrange(len(columns)):
