@@ -1,4 +1,4 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  svgmanager.py - The Manager of SVG
 #  Copyright (C) 2004 by Takuya KAWAHARA <num@sann.ne.jp>
@@ -11,15 +11,21 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: svgmanager.py,v 1.49 2008/05/22 12:31:08 atzm Exp $
+# $Id: svgmanager.py,v 1.52 2009/12/14 14:28:56 atzm Exp $
 
 import gtk, gobject
 import os, sys, shutil
 import string, re
 
+try:
+	import migemo
+except ImportError:
+	pass
+
 from showingsurface      import ShowingSurface
 from common              import *
 from viewer.viewercommon import *
+from viewer.ghostmanager import create_ghost
 import config
 
 class SVGManagerWindow(gtk.Window):
@@ -33,7 +39,7 @@ class SVGManagerWindow(gtk.Window):
 		## Create GhostList window
 
 		self.ghost_list_str = gtk.ListStore(gobject.TYPE_BOOLEAN, gobject.TYPE_STRING,
-									gobject.TYPE_BOOLEAN,  gobject.TYPE_STRING)
+											gobject.TYPE_BOOLEAN,  gobject.TYPE_STRING)
 
 		self.ghost_list = gtk.TreeView(self.ghost_list_str)
 		self.ghost_list.set_enable_search(True)
@@ -51,7 +57,7 @@ class SVGManagerWindow(gtk.Window):
 			gtk.TreeViewColumn(unicode(_('Ghost'), 'utf-8')),
 			gtk.TreeViewColumn(unicode(_('FMO'), 'utf-8')),
 			gtk.TreeViewColumn(unicode(_('Path'), 'utf-8')),
-			]
+		]
 		for i in xrange(len(columns)):
 			columns[i].set_resizable(True)
 			columns[i].set_clickable(True)
@@ -74,7 +80,6 @@ class SVGManagerWindow(gtk.Window):
 				columns[i].add_attribute(cell, 'text', i)
 				if   i == 1: cell.set_property('width', 80)
 				elif i == 2: cell.set_property('width', 40)
-				#else:        cell.set_property('width', 140) # FIXME : kimeuchi ikunai
 
 		self.sw = gtk.ScrolledWindow()
 		self.sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -135,7 +140,7 @@ class SVGManagerWindow(gtk.Window):
 		svg_cols = [
 			gtk.TreeViewColumn(),
 			gtk.TreeViewColumn(unicode(_('Ghost Status'), 'utf-8'))
-			]
+		]
 		for i in xrange(len(svg_cols)):
 			info_svg.append_column(svg_cols[i])
 			cell = gtk.CellRendererText()
@@ -221,21 +226,27 @@ class SVGManagerWindow(gtk.Window):
 
 	def open(self, widget=None, data=None):
 		self.show_all()
-		#self.ghost_list.grab_focus()
 
 	def close(self, widget=None, event=None, data=None):
 		self.hide()
 		return True
 
 	def sort(self, treeviewcol, col_num):
-		id = self.ghost_list_str.get_sort_column_id()
-		if id[0] == col_num:
-			self.ghost_list_str.set_sort_column_id(col_num, not id[1])
+		id_ = self.ghost_list_str.get_sort_column_id()
+		if id_[0] == col_num:
+			self.ghost_list_str.set_sort_column_id(col_num, not id_[1])
 		else:
 			self.ghost_list_str.set_sort_column_id(col_num, gtk.SORT_DESCENDING)
 
 	def search(self, widget=None, data=None):
-		pat = re.compile(self.search_entry.get_text(), re.IGNORECASE)
+		text = self.search_entry.get_text()
+
+		if globals().has_key('migemo') and config.get('migemo', 'migemo_enabled', 'boolean'):
+			m = migemo.Migemo(config.get('migemo', 'migemo_dict'))
+			pat = re.compile(m.query(unicode(text, 'utf-8')).encode('utf-8'), re.IGNORECASE)
+		else:
+			pat = re.compile(text, re.IGNORECASE)
+
 		current = self.selection()
 		rng = []
 
@@ -285,8 +296,8 @@ class SVGManagerWindow(gtk.Window):
 				widget.set_text(self.msg)
 
 	def scroll(self, widget, event):
-		if event.state == 1: # shift
-			if event.keyval == 65362: # up
+		if event.state == 1:            # shift
+			if event.keyval == 65362:   # up
 				self.sw.emit('scroll-child', gtk.SCROLL_PAGE_UP, False)
 				return True
 			elif event.keyval == 65364: # down
@@ -299,21 +310,21 @@ class SVGManagerWindow(gtk.Window):
 	def cursor_changed(self, treeview):
 		treeview.emit("select-cursor-row", False)
 
-	def set_info(self, ghost_name='', sakura='', unyu='', craftman='', hpname='', hpurl='', supported='',
-				 action='', text_path='', surface_path='', version='', info=''):
+	def set_info(self, ghost_name='', sakura='', unyu='', craftman='', hpname='', hpurl='',
+				 supported='', action='', text_path='', surface_path='', version='', info=''):
 		status = [
-			['sakura',		sakura],
-			['unyu',		unyu],
-			['craftman',	craftman],
-			['HPname',		hpname],
-			['URL',			hpurl],
-			['supported',	supported],
-			['action',		action],
-			['DEF.',		text_path],
-			['SUF.',		surface_path],
-			['Ver.',		version],
-			['info',		info],
-			]
+			['sakura',    sakura],
+			['unyu',      unyu],
+			['craftman',  craftman],
+			['HPname',    hpname],
+			['URL',       hpurl],
+			['supported', supported],
+			['action',    action],
+			['DEF.',      text_path],
+			['SUF.',      surface_path],
+			['Ver.',      version],
+			['info',      info],
+		]
 
 		self.info_svg_str.clear()
 		for l in status:
@@ -351,61 +362,25 @@ class SVGManagerWindow(gtk.Window):
 			return True
 
 		txt_path = expand_quote(self.ghost_list_str.get_value(self.ghost_list_str.get_iter(self.ghost_list.get_cursor()[0][0]), 3))
-		txt_path = os.path.join(self.ghostmanager.get_ghost_dir(), os.path.basename(txt_path))
-		g = self.ghostmanager.nominate_ghost_txt(txt_path)
-		if g is None:
+		txt_path = os.path.join(self.ghostmanager.get_basedir(), txt_path)
+		ghost    = create_ghost(txt_path)
+		if ghost is None:
 			self.error_info(txt_path)
-			#self.clear_info()
-			#self.set_info()
-			#self.info_svg_str.clear()
-			#self.sur_button.set_sensitive(False)
-			#self.url_button.set_sensitive(False)
-			#self.ghost_name.set_text(unicode(_(txt_path), 'utf-8') + unicode(_(' is NOT existing!!'), 'utf-8'))
-			#self.sakura_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
-			#self.unyuu_box.set_from_stock(gtk.STOCK_MISSING_IMAGE, gtk.ICON_SIZE_LARGE_TOOLBAR)
 			return True
 
 		## get and show sakura, unyuu surfaces
-		sur_sakura = g.get_surface(0)
-		sur_unyuu = g.get_surface(10)
+		sur_sakura = ghost.get_surface(0, SIDE_SAKURA)
+		sur_unyuu  = ghost.get_surface(10, SIDE_KERO)
 
 		self.sakura_box.set_from_pixbuf(sur_sakura)
 		self.unyuu_box.set_from_pixbuf(sur_unyuu)
 
-		hpurl = g.get_url()
-		#self.ghost_name.set_text(g.get_ghostname())
+		hpurl = ghost.get_url()
 
-		self.set_info(g.get_ghostname(), g.get_sakura(), g.get_unyu(), g.get_craftman(),
-					  g.get_hpname(), hpurl, g.get_supported(), g.get_sakura_action(), txt_path,
-					  os.path.join(self.ghostmanager.get_ghost_dir(), g.get_surfacefile()),
-					  g.get_update(), g.get_inform())
-
-# 		status = [
-# 			['sakura',		g.get_sakura()],
-# 			['unyu',		g.get_unyu()],
-# 			['craftman',	g.get_craftman()],
-# 			['HPname',		g.get_hpname()],
-# 			['URL',			hpurl],
-# 			['supported',	g.get_supported()],
-# 			['action',		g.get_sakura_action()],
-# 			['DEF.',		txt_path],
-# 			['SUF.',		os.path.join(self.ghostmanager.get_ghost_dir(), g.get_surfacefile())],
-# 			['Ver.',		g.get_update()],
-# 			['info',		g.get_inform()]
-# 			]
-
-# 		self.info_svg_str.clear()
-		
-# 		for i in xrange(len(status)):
-# 			self.info_svg_str.append(status[i])
-
-# 		if self.button_id:
-# 			self.url_button.disconnect(self.button_id)
-# 		self.button_id = None
-
-# 		if self.button_id_s:
-# 			self.sur_button.disconnect(self.button_id_s)
-# 		self.button_id_s = None
+		self.set_info(ghost.get_ghostname(), ghost.get_sakura(), ghost.get_unyu(), ghost.get_craftman(),
+					  ghost.get_hpname(), hpurl, ghost.get_supported(), ghost.get_sakura_action(), txt_path,
+					  os.path.join(os.path.dirname(txt_path), ghost.get_surfacefile()),
+					  ghost.get_update(), ghost.get_inform())
 
 		self.disconnect_buttons()
 
@@ -416,11 +391,10 @@ class SVGManagerWindow(gtk.Window):
 			self.url_button.set_sensitive(False)
 
 		self.sur_button.set_sensitive(True)
-		self.button_id_s = self.sur_button.connect("clicked", self.show_surface, g)
+		self.button_id_s = self.sur_button.connect("clicked", self.show_surface, ghost)
 
 	def _copy_svg(self, src_file, dest_file):
-		if os.path.exists(src_file) and os.path.exists(dest_file) and \
-			   os.path.samefile(src_file, dest_file):
+		if os.path.exists(src_file) and os.path.exists(dest_file) and os.path.samefile(src_file, dest_file):
 			return True
 
 		if os.path.exists(dest_file):
@@ -433,52 +407,57 @@ class SVGManagerWindow(gtk.Window):
 			d.destroy()
 			if not res or res != gtk.RESPONSE_YES:
 				return False
+
+		dest_dir = os.path.dirname(dest_file)
+		if not os.path.isdir(dest_dir):
+			try:
+				os.makedirs(dest_dir)
+			except OSError:
+				return False
+
 		try:
 			shutil.copyfile(src_file, dest_file)
 		except:
 			return False
 		return True
 
-	def copy_svg(self, src_textfile):
+	def copy_svg(self, src_textfile, dest_dir):
 		src_textfile = os.path.abspath(src_textfile)
-		ghost_dir    = self.ghostmanager.get_ghost_dir()
 
 		if not os.path.exists(src_textfile):
-			open_error_dialog(unicode(_('File not found'), 'utf-8') + \
-							  ': %s' % src_textfile, self)
-			return None
-		src_dir, textfile = os.path.split(src_textfile)
-		try:
-			ghost = self.ghostmanager.nominate_ghost_txt(textfile, src_dir)
-		except:
-			open_error_dialog(unicode(_('Invalid file'), 'utf-8') + \
-							  ': %s' % src_textfile, self)
-			return None
-		imagefile     = ghost.get_surfacefile()
-		src_imagefile = os.path.join(src_dir, imagefile)
-		if not os.path.exists(src_imagefile):
-			open_error_dialog(unicode(_('File not found'), 'utf-8') + \
-							  ': %s' % src_imagefile, self)
+			open_error_dialog(unicode(_('File not found'), 'utf-8') + ': %s' % src_textfile, self)
 			return None
 
-		dest_dir       = self.ghostmanager.get_ghost_dir()
-		dest_textfile  = os.path.join(ghost_dir, textfile)
-		dest_imagefile = os.path.join(ghost_dir, imagefile)
+		ghost = create_ghost(src_textfile)
+		if not ghost:
+			open_error_dialog(unicode(_('Invalid file'), 'utf-8') + ': %s' % src_textfile, self)
+			return None
+
+		imagefile     = ghost.get_surfacefile()
+		src_imagefile = os.path.join(os.path.dirname(ghost.get_path()), imagefile)
+		if not os.path.exists(src_imagefile):
+			open_error_dialog(unicode(_('File not found'), 'utf-8') + ': %s' % src_imagefile, self)
+			return None
+
+		dest_textfile  = os.path.join(dest_dir, os.path.basename(src_textfile))
+		dest_imagefile = os.path.join(dest_dir, os.path.basename(src_imagefile))
 
 		if self._copy_svg(src_textfile, dest_textfile):
 			if self._copy_svg(src_imagefile, dest_imagefile):
-				return ghost
+				return create_ghost(dest_textfile)
 			return None
 		return None
 
 ## if pressed button
 	def add_ghost(self, button):
-		ghost_dir = self.ghostmanager.get_ghost_dir()
-
-		filew = gtk.FileSelection()
+		ffilter = gtk.FileFilter()
+		ffilter.add_pattern('*.txt')
+		filew = gtk.FileChooserDialog(parent=self, action=gtk.FILE_CHOOSER_ACTION_OPEN,
+									  buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+											   gtk.STOCK_OK, gtk.RESPONSE_OK))
+		filew.set_filter(ffilter)
 		filew.set_select_multiple(False)
 		filew.connect("destroy", lambda x: filew.destroy())
-		filew.set_filename(os.path.normpath(os.path.join(ghost_dir, '*.txt')))
 		filew.show()
 		res = filew.run()
 		src_svg_file = filew.get_filename()
@@ -487,7 +466,8 @@ class SVGManagerWindow(gtk.Window):
 		if res != gtk.RESPONSE_OK:
 			return True
 
-		ghost = self.copy_svg(src_svg_file)
+		dest_dir = os.path.join(self.ghostmanager.get_basedir(), 'Ghost')
+		ghost    = self.copy_svg(src_svg_file, dest_dir)
 		if not ghost:
 			sys.stderr.write("!!! couldn't copy %s\n" % src_svg_file)
 			return True
@@ -500,9 +480,8 @@ class SVGManagerWindow(gtk.Window):
 			open_error_dialog(unicode(_("Couldn't open file"), 'utf-8'), self)
 			return True
 
-		self.ghost_list_str.append([True, ghost_name, '',
-							'"%s"' % os.path.join(os.path.basename(ghost_dir),
-												  os.path.basename(src_svg_file))])
+		dest_relpath = os.path.join(os.path.basename(dest_dir), os.path.basename(ghost.get_path()))
+		self.ghost_list_str.append([True, ghost_name, False, '"%s"' % dest_relpath])
 		self.ghost_list.set_cursor(len(self.ghost_list_str)-1)
 		return True
 
@@ -516,7 +495,6 @@ class SVGManagerWindow(gtk.Window):
 			else:
 				self.set_fmo(model, iter)
 			self.ghost_list.set_cursor(i)
-			#self.ghost_list.grab_focus()
 		except:
 			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
 
@@ -530,7 +508,6 @@ class SVGManagerWindow(gtk.Window):
 			else:
 				self.use_ghost(model, iter)
 			self.ghost_list.set_cursor(i)
-			#self.ghost_list.grab_focus()
 		except:
 			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
 
@@ -548,15 +525,11 @@ class SVGManagerWindow(gtk.Window):
 	def reload(self, button):
 		self.get_config()
 		self.app.notify_svg_changed()
-		#self.ghost_list.grab_focus()
 
 	def save(self, button):
 		self.set_config()
 		self.app.notify_svg_changed()
 
-	def get_ghost(self, ifghost):
-		return self.ghostmanager.nominate_ghost(ifghost)
-
 	def get_fmo_ghostnames(self):
 		return self.ghostmanager.get_fmo_ghostnames()
 
@@ -589,8 +562,8 @@ class SVGManagerWindow(gtk.Window):
 			open_error_dialog(unicode(_('No selected Ghost!'), 'utf-8'), self)
 
 	def show_surface(self, button, ghost):
-		path = os.path.join(self.ghostmanager.get_ghost_dir(), ghost.get_surfacefile())
 		try:
+			path   = os.path.join(os.path.dirname(ghost.get_path()), ghost.get_surfacefile())
 			pixbuf = gtk.gdk.pixbuf_new_from_file(path)
 		except:
 			return
@@ -598,12 +571,12 @@ class SVGManagerWindow(gtk.Window):
 
 	def get_config(self):
 		self.ghost_list_str.clear()
-		self.ghostmanager.generate_dictionary()
-		for line in self.ghostmanager.get_dict().values():
+		self.ghostmanager.load_ghost_text()
+		for line in self.ghostmanager.get_ghosts().values():
 			self.ghost_list_str.append(line)
 
 	def set_config(self):
-		self.ghostmanager.save_dictionary(self.ghost_list_str)
+		self.ghostmanager.save_ghost_text(self.ghost_list_str)
 
 	def use_ghost(self, model, iter):
 		## delete '#' from  first item '#GHOST'
