@@ -1,4 +1,4 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  textmanager.py - TextBuffer manipulator part for GBottler
 #  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: textmanager.py,v 1.41 2008/05/18 18:07:30 atzm Exp $
+# $Id: textmanager.py,v 1.42 2009/12/28 09:59:51 atzm Exp $
 #
 
 import os
@@ -147,22 +147,18 @@ class TextManager(gtk.TextView):
 		pos = self.textbuffer.get_iter_at_mark(self.textbuffer.get_insert()).get_offset() # cursor position
 		end = self.textbuffer.get_end_iter().get_offset()
 
-		#print 'string:', string
 		chunks = self.parser.parse(string)
-		#print 'start: ', chunks
 
 		self.textbuffer.set_text("")
 		for chunk in chunks:
 			if chunk[0] == TEXT_STRING:
 				for n in xrange(len(chunk[1])):
 					if chunk[1][n][0] in [SCRIPT_TEXT, TEXT_META]:
-						c = chunk[1][n][1]#.replace("\\", r"\\")
-						#c = c.replace("%", r"\%")
-						#c = c.replace(r"\]", "]")
+						c = chunk[1][n][1]
 						self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 															 c, current[-1])
 					elif chunk[1][n][0] == PARSE_ERROR:
-						c = chunk[1][n][1]#.replace("\\", r"\\")
+						c = chunk[1][n][1]
 						self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 															 c, 'error')
 
@@ -178,8 +174,8 @@ class TextManager(gtk.TextView):
 						current = ['kero']
 				elif name == r'\_s':
 					if current[-1] == 'sync' and len(current) > 1:
-						current.pop()
 						# when synchronized session closed
+						current.pop()
 					else:
 						current.append('sync')
 
@@ -201,7 +197,7 @@ class TextManager(gtk.TextView):
 				for n in xrange(len(args)):
 					if type(args[0]) is TupleType:
 						try:
-							if args[n][0][0] == PARSE_ERROR:# and name == r'\n':
+							if args[n][0][0] == PARSE_ERROR:
 								self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 																	 "%s" % args[n][0][1], 'error')
 							else:
@@ -216,7 +212,6 @@ class TextManager(gtk.TextView):
 		[si, ei] = self.textbuffer.get_bounds()
 		self.textbuffer.apply_tag_by_name('font', si, ei)
 
-		#self.textbuffer.insert(self.textbuffer.get_end_iter(), '\n')
 		if end != pos:
 			if end != 0:
 				self.emit('move-cursor', gtk.MOVEMENT_LOGICAL_POSITIONS, end*-1, False)
@@ -248,8 +243,8 @@ class TextManager(gtk.TextView):
 						current = ['kero']
 				elif name == r'\_s':
 					if current[-1] == 'sync' and len(current) > 1:
-						current.pop()
 						# when synchronized session closed
+						current.pop()
 					else:
 						current.append('sync')
 
@@ -309,12 +304,18 @@ class TextManager(gtk.TextView):
 									tmp = '%s[%s]' % (name, args[n][0][1])
 									self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 																			 tmp, tag)
+
+								if self.view_style == STYLE_SCRIPT_WITH_LINEFEED and name == r'\n':
+									self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
+																			 '\n', tag)
 						else:
 							self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(),
 																	 format % (name, args[n]), tag)
 
-					if self.view_style == STYLE_SCRIPT_WITH_LINEFEED and name == r'\n':
-						self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(), '\\n\n', tag)
+					if name == r'\n' and not args:
+						self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(), r'\n', tag)
+						if self.view_style == STYLE_SCRIPT_WITH_LINEFEED:
+							self.textbuffer.insert_with_tags_by_name(self.textbuffer.get_end_iter(), '\n', tag)
 
 		self.textbuffer.insert(self.textbuffer.get_end_iter(), '\n')
 		[si, ei] = self.textbuffer.get_bounds()
