@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: xmllogger.py,v 1.8 2005/08/29 19:03:24 atzm Exp $
+# $Id: xmllogger.py,v 1.9 2007/09/14 19:07:32 atzm Exp $
 #
 
 import os, sys, time
@@ -148,7 +148,7 @@ class XMLLogger:
 		for line in lists:
 			line = map(self.conv_xml, line)
 			datetime, ghost, channel, votes, agrees, script, mid = line
-			xmlline = (XML_LINE % (mid, datetime, channel, script, votes, agrees, ghost)).encode('sjis')
+			xmlline = (XML_LINE % (mid, datetime, channel, script, votes, agrees, ghost)).encode('sjis', 'xmlcharrefreplace')
 			file.write(xmlline)
 		file.write('</bottlelog>\r\n')
 		file.close()
